@@ -1,13 +1,13 @@
 package resource
 
 import (
+	"context"
+
 	rbacapi "k8s.io/api/rbac/v1"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 	"k8s.io/apimachinery/pkg/runtime"
 	rbacset "k8s.io/client-go/kubernetes/typed/rbac/v1"
 	rbaclisters "k8s.io/client-go/listers/rbac/v1"
-
-	imageregistryv1 "github.com/openshift/api/imageregistry/v1"
 )
 
 var _ Mutator = &generatorClusterRole{}
@@ -17,7 +17,7 @@ type generatorClusterRole struct {
 	client rbacset.RbacV1Interface
 }
 
-func newGeneratorClusterRole(lister rbaclisters.ClusterRoleLister, client rbacset.RbacV1Interface, cr *imageregistryv1.Config) *generatorClusterRole {
+func newGeneratorClusterRole(lister rbaclisters.ClusterRoleLister, client rbacset.RbacV1Interface) *generatorClusterRole {
 	return &generatorClusterRole{
 		lister: lister,
 		client: client,
@@ -28,14 +28,6 @@ func (gcr *generatorClusterRole) Type() runtime.Object {
 	return &rbacapi.ClusterRole{}
 }
 
-func (gcr *generatorClusterRole) GetGroup() string {
-	return rbacapi.GroupName
-}
-
-func (gcr *generatorClusterRole) GetResource() string {
-	return "clusterroles"
-}
-
 func (gcr *generatorClusterRole) GetNamespace() string {
 	return ""
 }
@@ -108,18 +100,24 @@ func (gcr *generatorClusterRole) Get() (runtime.Object, error) {
 
 func (gcr *generatorClusterRole) Create() (runtime.Object, error) {
 	return commonCreate(gcr, func(obj runtime.Object) (runtime.Object, error) {
-		return gcr.client.ClusterRoles().Create(obj.(*rbacapi.ClusterRole))
+		return gcr.client.ClusterRoles().Create(
+			context.TODO(), obj.(*rbacapi.ClusterRole), metav1.CreateOptions{},
+		)
 	})
 }
 
 func (gcr *generatorClusterRole) Update(o runtime.Object) (runtime.Object, bool, error) {
 	return commonUpdate(gcr, o, func(obj runtime.Object) (runtime.Object, error) {
-		return gcr.client.ClusterRoles().Update(obj.(*rbacapi.ClusterRole))
+		return gcr.client.ClusterRoles().Update(
+			context.TODO(), obj.(*rbacapi.ClusterRole), metav1.UpdateOptions{},
+		)
 	})
 }
 
-func (gcr *generatorClusterRole) Delete(opts *metav1.DeleteOptions) error {
-	return gcr.client.ClusterRoles().Delete(gcr.GetName(), opts)
+func (gcr *generatorClusterRole) Delete(opts metav1.DeleteOptions) error {
+	return gcr.client.ClusterRoles().Delete(
+		context.TODO(), gcr.GetName(), opts,
+	)
 }
 
 func (g *generatorClusterRole) Owned() bool {
